%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% MAIN SCRIPT
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc
clear all
format long

%Create design space of feasible vessels
[Design_Space,Design] = Create_Design_Space_Patrol();

[Fleet_Space_Infeasible] = Create_Fleet_Space_infeasible();

%Create feasible fleet space
[Fleet_Space] = Create_Fleet_Space(Fleet_Space_Infeasible);

%Create attributes
[Attribute_Nr_PatDays,Attribute_Nr_Vessels,Attribute_Range,...
    Attribute_Endurance,Attribute_Speed,Attribute_Helicopter,...
    Attribute_Smallboat,Attribute_Sensors, Attribute_Arctic,...
    Attribute_Crew,Attribute_Oil_Rec,Attribute_Bollard_Pull] =...
    Performance_Attributes();

%Calculate normalized performance score for each vessel
[Vessel_Score_Range,Vessel_Score_Speed,Vessel_Score_Crew,...
 Vessel_Score_Helicopter,Vessel_Score_Smallboat,Vessel_Score_Sensor,...
 Vessel_Score_Ice,Vessel_Score_OilRec,Vessel_Score_Tugging] =...
 Normalization_Score_Vessel(Design_Space,Attribute_Range,...
 Attribute_Speed,Attribute_Crew,Attribute_Helicopter,...
 Attribute_Smallboat,Attribute_Sensors,...
 Attribute_Arctic,Attribute_Oil_Rec,Attribute_Bollard_Pull);

%Calculate single-attribute utilities for each fleet
[Range_Utility_Fleet,Speed_Utility_Fleet,Crew_Utility_Fleet,...
    Helicopter_Utility_Fleet,Smallboat_Utility_Fleet,...
    Sensor_Utility_Fleet,Ice_Utility_Fleet,...
    OilRec_Utility_Fleet,Tugging_Utility_Fleet] = SAU(Fleet_Space,...
    Vessel_Score_Range,Vessel_Score_Speed,Vessel_Score_Crew,...
    Vessel_Score_Helicopter,Vessel_Score_Smallboat,Vessel_Score_Sensor,...
    Vessel_Score_Ice,Vessel_Score_OilRec,Vessel_Score_Tugging);
 
%Calculate CAPEX for all fleet alternatives
[Fleet_Cost_CAPEX] = Calculate_Fleet_CAPEX(Fleet_Space);

%Calculate yearly OPEX for all fleet alternatives
[Fleet_Cost_OPEX] = Calculate_Fleet_OPEX(Fleet_Space);

%Calculate fleet patrol days
[Patrol_Days_Fleet] = Create_Patrol_Days(Fleet_Space);

%Create epoch space
[Epoch_Space] = Create_Epoch_Space();

%Create weights for the MAU function
 [Weights] = Create_Weights_MAU(Epoch_Space);

%Utility of each fleet in each epoch
[Epoch_Fleet_Utility] = Utility_Epoch(Range_Utility_Fleet,...
    Speed_Utility_Fleet,Crew_Utility_Fleet,Helicopter_Utility_Fleet,...
    Smallboat_Utility_Fleet,Sensor_Utility_Fleet,Ice_Utility_Fleet,...
    OilRec_Utility_Fleet,Tugging_Utility_Fleet,Weights,Fleet_Space,...
    Patrol_Days_Fleet);

%Calculate average utility over all epochs
 Find_Average_Utility;
 
% Find the pareto fleets in all epochs       
[Pareto_Set]...
     = Pareto_Solutions_All_Epochs(Epoch_Fleet_Utility,Fleet_Space,...
                                   Fleet_Cost_CAPEX);

% Plot pareto
Create_Pareto_Plots;

% Find pareto trace
 Find_Pareto_Trace;

%Calculate NPV for all fleets 
[NPV_Fleets,Flow] = Calculate_NPV(Fleet_Cost_CAPEX,Fleet_Cost_OPEX);

%% Write results to execl
%Write pareto trace to excel
filename = 'Results.xlsx';
A = Pareto_Trace_temp;
sheet = 1;
xlrange = 'B3';
xlswrite(filename,A,sheet,xlrange); 

%Write epoch utility for all fleets to excel
filename = 'Results.xlsx';
B = Epoch_Fleet_Utility;
sheet = 3;
xlrange = 'C4';
xlswrite(filename,B,sheet,xlrange); 

%Write average fleet utility
filename = 'Results.xlsx';
B = Average_Utility_Fleet;
sheet = 4;
xlrange = 'C4';
xlswrite(filename,B,sheet,xlrange); 

%Write pareto epoch 1 results to excel
filename = 'Results.xlsx';
C = Epoch1_Pareto_utility_cost;
sheet = 2;
xlrange = 'B5';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch1_Pareto_Designs;
sheet = 2;
xlrange = 'E5';
xlswrite(filename,C,sheet,xlrange); 

%Write pareto epoch 2 results to excel
filename = 'Results.xlsx';
C = Epoch2_Pareto_utility_cost;
sheet = 2;
xlrange = 'P5';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch2_Pareto_Designs;
sheet = 2;
xlrange = 'S5';
xlswrite(filename,C,sheet,xlrange); 

%Write pareto epoch 3 results to excel
filename = 'Results.xlsx';
C = Epoch3_Pareto_utility_cost;
sheet = 2;
xlrange = 'AD5';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch3_Pareto_Designs;
sheet = 2;
xlrange = 'AG5';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 4 results to excel
filename = 'Results.xlsx';
C = Epoch4_Pareto_utility_cost;
sheet = 2;
xlrange = 'AR5';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch4_Pareto_Designs;
sheet = 2;
xlrange = 'AU5';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 5 results to excel
filename = 'Results.xlsx';
C = Epoch5_Pareto_utility_cost;
sheet = 2;
xlrange = 'BF5';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch5_Pareto_Designs;
sheet = 2;
xlrange = 'BI5';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 6 results to excel
filename = 'Results.xlsx';
C = Epoch6_Pareto_utility_cost;
sheet = 2;
xlrange = 'B35';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch6_Pareto_Designs;
sheet = 2;
xlrange = 'E35';
xlswrite(filename,C,sheet,xlrange); 

%Write pareto epoch 7 results to excel
filename = 'Results.xlsx';
C = Epoch7_Pareto_utility_cost;
sheet = 2;
xlrange = 'P35';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch7_Pareto_Designs;
sheet = 2;
xlrange = 'S35';
xlswrite(filename,C,sheet,xlrange); 

%Write pareto epoch 8 results to excel
filename = 'Results.xlsx';
C = Epoch8_Pareto_utility_cost;
sheet = 2;
xlrange = 'AD35';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch8_Pareto_Designs;
sheet = 2;
xlrange = 'AG35';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 9 results to excel
filename = 'Results.xlsx';
C = Epoch9_Pareto_utility_cost;
sheet = 2;
xlrange = 'AR35';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch9_Pareto_Designs;
sheet = 2;
xlrange = 'AU35';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 10 results to excel
filename = 'Results.xlsx';
C = Epoch10_Pareto_utility_cost;
sheet = 2;
xlrange = 'BF35';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch10_Pareto_Designs;
sheet = 2;
xlrange = 'BI35';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 11 results to excel
filename = 'Results.xlsx';
C = Epoch11_Pareto_utility_cost;
sheet = 2;
xlrange = 'B64';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch11_Pareto_Designs;
sheet = 2;
xlrange = 'E64';
xlswrite(filename,C,sheet,xlrange); 

%Write pareto epoch 12 results to excel
filename = 'Results.xlsx';
C = Epoch12_Pareto_utility_cost;
sheet = 2;
xlrange = 'P64';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch12_Pareto_Designs;
sheet = 2;
xlrange = 'S64';
xlswrite(filename,C,sheet,xlrange); 

%Write pareto epoch 13 results to excel
filename = 'Results.xlsx';
C = Epoch13_Pareto_utility_cost;
sheet = 2;
xlrange = 'AD64';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch13_Pareto_Designs;
sheet = 2;
xlrange = 'AG64';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 14 results to excel
filename = 'Results.xlsx';
C = Epoch14_Pareto_utility_cost;
sheet = 2;
xlrange = 'AR64';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch14_Pareto_Designs;
sheet = 2;
xlrange = 'AU64';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 15 results to excel
filename = 'Results.xlsx';
C = Epoch15_Pareto_utility_cost;
sheet = 2;
xlrange = 'BF64';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch15_Pareto_Designs;
sheet = 2;
xlrange = 'BI64';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 16 results to excel
filename = 'Results.xlsx';
C = Epoch16_Pareto_utility_cost;
sheet = 2;
xlrange = 'B93';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch16_Pareto_Designs;
sheet = 2;
xlrange = 'E93';
xlswrite(filename,C,sheet,xlrange); 

%Write pareto epoch 17 results to excel
filename = 'Results.xlsx';
C = Epoch17_Pareto_utility_cost;
sheet = 2;
xlrange = 'P93';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch17_Pareto_Designs;
sheet = 2;
xlrange = 'S93';
xlswrite(filename,C,sheet,xlrange); 

%Write pareto epoch 18 results to excel
filename = 'Results.xlsx';
C = Epoch18_Pareto_utility_cost;
sheet = 2;
xlrange = 'AD93';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch18_Pareto_Designs;
sheet = 2;
xlrange = 'AG93';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 19 results to excel
filename = 'Results.xlsx';
C = Epoch19_Pareto_utility_cost;
sheet = 2;
xlrange = 'AR93';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch19_Pareto_Designs;
sheet = 2;
xlrange = 'AU93';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 20 results to excel
filename = 'Results.xlsx';
C = Epoch20_Pareto_utility_cost;
sheet = 2;
xlrange = 'BF93';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch20_Pareto_Designs;
sheet = 2;
xlrange = 'BI93';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 21 results to excel
filename = 'Results.xlsx';
C = Epoch21_Pareto_utility_cost;
sheet = 2;
xlrange = 'B121';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch21_Pareto_Designs;
sheet = 2;
xlrange = 'E121';
xlswrite(filename,C,sheet,xlrange); 

%Write pareto epoch 22 results to excel
filename = 'Results.xlsx';
C = Epoch22_Pareto_utility_cost;
sheet = 2;
xlrange = 'P121';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch22_Pareto_Designs;
sheet = 2;
xlrange = 'S121';
xlswrite(filename,C,sheet,xlrange); 

%Write pareto epoch 23 results to excel
filename = 'Results.xlsx';
C = Epoch23_Pareto_utility_cost;
sheet = 2;
xlrange = 'AD121';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch23_Pareto_Designs;
sheet = 2;
xlrange = 'AG121';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 24 results to excel
filename = 'Results.xlsx';
C = Epoch24_Pareto_utility_cost;
sheet = 2;
xlrange = 'AR121';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch24_Pareto_Designs;
sheet = 2;
xlrange = 'AU121';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 25 results to excel
filename = 'Results.xlsx';
C = Epoch25_Pareto_utility_cost;
sheet = 2;
xlrange = 'BF121';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch25_Pareto_Designs;
sheet = 2;
xlrange = 'BI121';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 26 results to excel
filename = 'Results.xlsx';
C = Epoch26_Pareto_utility_cost;
sheet = 2;
xlrange = 'B149';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch26_Pareto_Designs;
sheet = 2;
xlrange = 'E149';
xlswrite(filename,C,sheet,xlrange); 

%Write pareto epoch 27 results to excel
filename = 'Results.xlsx';
C = Epoch27_Pareto_utility_cost;
sheet = 2;
xlrange = 'P149';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch27_Pareto_Designs;
sheet = 2;
xlrange = 'S149';
xlswrite(filename,C,sheet,xlrange); 

%Write pareto epoch 28 results to excel
filename = 'Results.xlsx';
C = Epoch28_Pareto_utility_cost;
sheet = 2;
xlrange = 'AD149';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch28_Pareto_Designs;
sheet = 2;
xlrange = 'AG149';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 29 results to excel
filename = 'Results.xlsx';
C = Epoch29_Pareto_utility_cost;
sheet = 2;
xlrange = 'AR149';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch29_Pareto_Designs;
sheet = 2;
xlrange = 'AU149';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 30 results to excel
filename = 'Results.xlsx';
C = Epoch30_Pareto_utility_cost;
sheet = 2;
xlrange = 'BF149';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch30_Pareto_Designs;
sheet = 2;
xlrange = 'BI149';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 31 results to excel
filename = 'Results.xlsx';
C = Epoch31_Pareto_utility_cost;
sheet = 2;
xlrange = 'B177';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch31_Pareto_Designs;
sheet = 2;
xlrange = 'E177';
xlswrite(filename,C,sheet,xlrange);

%Write pareto epoch 32 results to excel
filename = 'Results.xlsx';
C = Epoch32_Pareto_utility_cost;
sheet = 2;
xlrange = 'P177';
xlswrite(filename,C,sheet,xlrange); 
filename = 'Results.xlsx';
C = Epoch32_Pareto_Designs;
sheet = 2;
xlrange = 'S177';
xlswrite(filename,C,sheet,xlrange);

%Write fleet space to excel
filename = 'Results.xlsx';
C = Fleet_Space;
sheet = 6;
xlrange = 'C4';
xlswrite(filename,C,sheet,xlrange); 

%Write NPV to excel
filename = 'Results.xlsx';
C = NPV_Fleets;
sheet = 7;
xlrange = 'C4';
xlswrite(filename,C,sheet,xlrange); 

