%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% This function calculates normalized vessel score against each 
%% performance attribute
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [Vessel_Score_Range,Vessel_Score_Speed,Vessel_Score_Crew,...
 Vessel_Score_Helicopter,Vessel_Score_Smallboat,Vessel_Score_Sensor,...
 Vessel_Score_Ice,Vessel_Score_OilRec,Vessel_Score_Tugging] =...
 Normalization_Score_Vessel(Design_Space,Attribute_Range,...
 Attribute_Speed,Attribute_Crew,Attribute_Helicopter,...
 Attribute_Smallboat,Attribute_Sensors,...
 Attribute_Arctic,Attribute_Oil_Rec,Attribute_Bollard_Pull)




%% Initialize normalized utility leveles:
%Attribute 'range':
Utility_Range_min = min(Attribute_Range);
Utility_Range_max = max(Attribute_Range);

%Attribute 'speed':
Utility_Speed_min = min(Attribute_Speed);
Utility_Speed_max = max(Attribute_Speed);

%Attribute 'crew':
Utility_Crew_min = min(Attribute_Crew);
Utility_Crew_max = max(Attribute_Crew);

%Attribute 'Helicopter':
Utility_Helicopter_min = min(Attribute_Helicopter);
Utility_Helicopter_max = max(Attribute_Helicopter);

%Attribute 'Small boat'
Utility_Smallboat_min = min(Attribute_Smallboat);
Utility_Smallboat_max = max(Attribute_Smallboat);

%Attribute 'sensor capability':
Utility_Sensors_min = 0;
Utility_Sensors_max = max(Attribute_Sensors);

%Attribute 'ice capability'
Utility_Ice_min = 0;
Utility_Ice_max = max(Attribute_Arctic);

%Attribute 'Oil Recovery'
Utility_OilRec_min = min(Attribute_Oil_Rec);
Utility_OilRec_max = max(Attribute_Oil_Rec);

%Attribute 'Bollard Pull'
Utility_BollardPull_min = min(Attribute_Bollard_Pull);
Utility_BollardPull_max = max(Attribute_Bollard_Pull);

%Initialize vessel performance against attributes
[Vessel_type,b] = size(Design_Space);
Vessel_Score_Range = zeros(Vessel_type,1);
Vessel_Score_Speed = zeros(Vessel_type,1);
Vessel_Score_Crew = zeros(Vessel_type,1);
Vessel_Score_Helicopter = zeros(Vessel_type,1);
Vessel_Score_Smallboat = zeros(Vessel_type,1);
Vessel_Score_Sensor = zeros(Vessel_type,1);
Vessel_Score_Ice = zeros(Vessel_type,1);
Vessel_Score_OilRec = zeros(Vessel_type,1);,
Vessel_Score_Tugging = zeros(Vessel_type,1);

%Loop normalized range score pr vessel
for i = 1:Vessel_type
     Vessel_Score_Range(i) = (Design_Space(i)-Utility_Range_min)/...
         (Utility_Range_max-Utility_Range_min);     
end %end loop i

%Loop normalized speed score pr vessel
for i = 1:Vessel_type
     Vessel_Score_Speed(i) = (Design_Space(i,2)-Utility_Speed_min)/...
         (Utility_Speed_max-Utility_Speed_min);     
end %end loop i

%Loop normalized crew score pr vessel
for i = 1:Vessel_type
     Vessel_Score_Crew(i) = (Design_Space(i,8)-Utility_Crew_min)/...
         (Utility_Crew_max-Utility_Crew_min);     
end %end loop i

%Loop normalized helictopter score pr vessel
for i = 1:Vessel_type
     Vessel_Score_Helicopter(i) = (Design_Space(i,3)-Utility_Helicopter_min)/...
         (Utility_Helicopter_max-Utility_Helicopter_min);     
end %end loop i

%Loop normalized smallboat score pr vessel
for i = 1:Vessel_type
     Vessel_Score_Smallboat(i) = (Design_Space(i,4)-Utility_Smallboat_min)/...
         (Utility_Smallboat_max-Utility_Smallboat_min);     
end %end loop i

%Loop normalized sensor score pr vessel
for i = 1:Vessel_type
     Vessel_Score_Sensor(i) = (Design_Space(i,6)-Utility_Sensors_min)/...
         (Utility_Sensors_max-Utility_Sensors_min);     
end %end loop i

%Loop normalized ice score pr vessel
for i = 1:Vessel_type
     Vessel_Score_Ice(i) = (Design_Space(i,7)-Utility_Ice_min)/...
         (Utility_Ice_max-Utility_Ice_min);     
end %end loop i

%Loop normalized oil recovery score pr vessel
for i = 1:Vessel_type
     Vessel_Score_OilRec(i) = (Design_Space(i,9)-Utility_OilRec_min)/...
         (Utility_OilRec_max-Utility_OilRec_min);     
end %end loop i

%Loop normalized tugging score pr vessel
for i = 1:Vessel_type
     Vessel_Score_Tugging(i) = (Design_Space(i,10)-...
         Utility_BollardPull_min )/...
         (Utility_BollardPull_max -Utility_BollardPull_min );     
end %end loop i

end